@@ -9,7 +9,7 @@ mcom_fn_list_define = [
     "v2dx", "flash", "plot", "figure", "hold", "box", "pause", "clf", "xlim", "ylim", "xlabel", 
     "ylabel", "drawnow", "v2d", "v2d_init", "v3d_init", "v2L", "title", "plot3", "grid", "v3dx", "v2d_show", 
     "v2d_pop", "v2d_line_object", "v2d_clear", "v2d_add_terrain", "set_style", "set_env", "use_geometry", 
-    "geometry_rotate_scale_translate", "test_function_terrain", 'line3d', 'advanced_geometry_rotate_scale_translate'
+    "geometry_rotate_scale_translate", "test_function_terrain", 'line3d', 'advanced_geometry_rotate_scale_translate',
 ]
 别名对齐 = [
     ('初始化3D', 'v2d_init'),
@@ -54,6 +54,7 @@ class mcom():
         self.digit = digit
         self.rapid_flush = rapid_flush
         self.flow_cnt = 0
+        self.tag = tag
         print蓝('[mcom.py]: log file at:' + self.starting_file)
 
         if not self.draw_mode=='Threejs':
@@ -310,6 +311,7 @@ class tcp_server():
         import threading
         self.sock, _ = self.draw_cmd_socket.accept()
         t = threading.Thread(target=self.listening_thread)
+        t.daemon = True
         t.start()
 
     def listening_thread(self):
@@ -422,7 +424,7 @@ class DrawProcessThreejs(Process):
     def init_threejs(self):
         import threading
         t = threading.Thread(target=self.run_flask, args=(find_free_port(),))
-        # t = threading.Thread(target=self.run_flask, args=(51241,))
+        t.daemon = True
         t.start()
 
     def run(self):
@@ -437,6 +439,9 @@ class DrawProcessThreejs(Process):
             self.__del__()
         self.__del__()
 
+    def __del__(self):
+        return
+        
     def run_handler(self, new_buff_list):
         self.buffer_list.extend(new_buff_list)
         if self.allow_backup:
